Border class

use WBorder to use the default Flutter Border widget

Constructors

Border({double? width, BorderStyle? style, Color? color, double? strokeAlign, double opacity = 1})
This is the elbe border. Use WBorder for the Flutter border. You can also use the toDeco method to convert this border to a BoxDecoration.
const

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
opacity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeAlign double?
final
style BorderStyle?
final
width double?
final

Methods

copyWith({double? width, BorderStyle? style, double? strokeAlign, Color? color}) Border
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolved(ElbeThemeData theme) Border
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

inherit → const Border
a shortcut for Border()
none → const Border