ColorKinds enum

these are the different main types of colors that can be used in the app

Inheritance
Available extensions

Values

accent → const ColorKinds
const ColorKinds(Icons.info)
info → const ColorKinds
const ColorKinds(Icons.info)
success → const ColorKinds
const ColorKinds(Icons.alertTriangle)
warning → const ColorKinds
const ColorKinds(Icons.alertTriangle)
error → const ColorKinds
const ColorKinds(Icons.xOctagon)

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ColorKinds>
A constant List of the values in this enum, in order of their declaration.