ColorThemeData class

Inheritance

Constructors

ColorThemeData.preset({ColorThemeValues values = const ColorThemeValues(), ColorThemeSelection selection = const ColorThemeSelection(), ColorThemeSelectors? selectors, ContrastColor? hierarchy})

Properties

hashCode int
The hash code for this object.
no setterinherited
hierarchy ContrastColor
latefinal
isDark bool
shorthand for selection.mode.isDark
no setter
isHighVis bool
shorthand for selection.constrast.isHighVis
no setter
map JsonMap
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected LayerColor
latefinal
selection ColorThemeSelection
final
values ColorThemeValues
final

Methods

asMaterialTheme() ColorScheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({ColorContrasts? contrast, ColorModes? mode, ColorSchemes? scheme, ColorKinds? kind, ColorManners? manner, ColorStates? state}) LayerColor
get the currently selected color
toString() String
A string representation of this object.
inherited
withSelection(ColorThemeSelection selection) ColorThemeData

Operators

operator ==(Object other) bool
The equality operator.
inherited