ColorThemeSelection class
Constructors
- ColorThemeSelection({ColorContrasts contrast = ColorContrasts.normal, ColorModes mode = ColorModes.light, ColorSchemes scheme = ColorSchemes.primary, ColorKinds kind = ColorKinds.accent, ColorManners manner = ColorManners.plain, ColorStates state = ColorStates.neutral})
-
const
Properties
- contrast → ColorContrasts
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → ColorKinds
-
final
- manner → ColorManners
-
final
- map → JsonMap
-
no setteroverride
- mode → ColorModes
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheme → ColorSchemes
-
final
- state → ColorStates
-
final
Methods
-
apply(
ContrastColor color) → LayerColor -
copyWith(
{ColorContrasts? contrast, ColorModes? mode, ColorSchemes? scheme, ColorKinds? kind, ColorManners? manner, ColorStates? state}) → ColorThemeSelection -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited