ElbeThemeData class

Inheritance

Constructors

ElbeThemeData({required ColorThemeData color, required TypeThemeData type, required GeometryThemeData geometry})
ElbeThemeData.preset({ColorThemeData? color, TypeThemeData? type, GeometryThemeData? geometry})

Properties

color ColorThemeData
final
geometry GeometryThemeData
final
hashCode int
The hash code for this object.
no setterinherited
map JsonMap
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TypeThemeData
final

Methods

copyWith({ColorThemeData? color, TypeThemeData? type, GeometryThemeData? geometry}) ElbeThemeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withColorSelection({ColorContrasts? contrast, ColorModes? mode, ColorSchemes? scheme, ColorKinds? kind, ColorManners? manner, ColorStates? state}) ElbeThemeData

Operators

operator ==(Object other) bool
The equality operator.
inherited