GeometryThemeData class

Inheritance

Constructors

GeometryThemeData({required double remSize, required double borderWidth, required double borderRadius, required BorderStyle borderStyle, required double borderAlign})
const
GeometryThemeData.preset({double remSize = 16, double borderWidth = .125, double borderRadius = .5, BorderStyle borderStyle = BorderStyle.solid, double borderAlign = BorderSide.strokeAlignInside})

Properties

borderAlign double
final
borderRadius double
final
borderStyle BorderStyle
final
borderWidth double
final
hashCode int
The hash code for this object.
no setterinherited
map JsonMap
no setteroverride
remSize double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? borderWidth, double? borderRadius, BorderStyle? borderStyle, double? remSize, bool? buttonBorder, double? borderAlign}) GeometryThemeData
maybeRem(double? dim) double?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rem(double dim) double
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited