RemInsets class
Insets in rem units. Works analogously to EdgeInsets but in rem units.
Constructors
- RemInsets({double left = 0, double top = 0, double right = 0, double bottom = 0})
-
define each side of the insets separately
const
- RemInsets.all(double value)
-
apply the same value to all sides. Define this through
valueconst - RemInsets.fromLTRB(double left, double top, double right, double bottom)
-
apply different values to each side. Define this through
left,top,right, andbottomconst - RemInsets.symmetric({double horizontal = 0, double vertical = 0})
-
apply the same value to the vertical and horizontal sides. Define this
through
horizontalandverticalconst
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPixel(
BuildContext context) → EdgeInsets - when using widgets from other libraries, you might need to convert the rem units to pixels. Use this method to do so.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited