TypeStyle class

Inheritance

Constructors

TypeStyle({TypeVariants variant = TypeVariants.regular, rem fontSize = 1, double? iconFactor, List<FontFeature>? fontFeatures, TextDecoration? decoration, String? fontFamily, String? package})
const

Properties

bold TypeStyle
no setter
decoration TextDecoration?
final
fontFamily String?
final
fontFeatures List<FontFeature>?
final
fontSize rem
final
hashCode int
The hash code for this object.
no setterinherited
iconFactor double
final
iconSize rem
no setter
italic TypeStyle
no setter
map JsonMap
no setteroverride
package String?
final
regular TypeStyle
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant TypeVariants
final

Methods

copyWith({TypeVariants? variant, double? fontSize, double? iconFactor, TextDecoration? decoration, List<FontFeature>? fontFeatures, String? fontFamily, String? package}) TypeStyle
merge(TypeStyle? style) TypeStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toTextStyle(BuildContext context, [Color? color]) TextStyle

Operators

operator ==(Object other) bool
The equality operator.
inherited