AppContextData class
Constructors
- AppContextData(void _onUpdated({AppLayoutMode? layoutMode, String? name}), {required bool hasMenu, required String name, required AppLayoutMode layoutMode, required _ElbeRouterInterface router})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMenu → bool
-
final
- layoutMode → AppLayoutMode
-
final
-
map
→ Map<
String, dynamic> -
no setteroverride
-
final
- name → String
-
final
- router → _ElbeRouterInterface
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
{String? name, AppLayoutMode? layoutMode}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited