Border class
use WBorder to use the default Flutter Border widget
Constructors
- Border({double? width, BorderStyle? style, Color? color, double? strokeAlign})
-
This is the elbe border. Use
WBorderfor the Flutter border. You can also use thetoDecomethod to convert this border to aBoxDecoration.const
Properties
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeAlign → double?
-
final
- style → BorderStyle?
-
final
- width → double?
-
final
Methods
-
copyWith(
{double? width, BorderStyle? style, double? strokeAlign, Color? color}) → Border -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolved(
ElbeThemeData t) → Border -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited