Card class
a card is an interactive box with styling and geometry options
- Inheritance
- Available extensions
Constructors
- Card({Key? key, Clip? clipBehavior, ColorSchemes? scheme, ColorKinds? kind, ColorManners? manner, ColorStates? state, RemInsets? margin, Color? color, RemInsets? padding = const RemInsets.all(1), RemConstraints? constraints, Border? border, double? width, double? height, VoidCallback? onTap, VoidCallback? onLongTap, String? heroTag, double? radius, BorderRadius? borderRadius, int? flex, required Widget child})
-
create a card by providing all properties. Cards are interactive boxes
with styling and geometry options
const
Properties
- border → Border?
-
final
- borderRadius → BorderRadius?
-
you can also use radius for a simple border radius, which will be merged with the theme's geometry settings.
final
- child → Widget
-
final
- clipBehavior → Clip?
-
final
- color → Color?
-
final
- constraints → RemConstraints?
-
final
- expanded → Expanded
-
Available on Widget, provided by the ExpandedWidget extension
wraps the widget in an Expandedno setter - fitHeight → IntrinsicHeight
-
Available on Widget, provided by the ExpandedWidget extension
wraps the widget in a IntrinsicHeightno setter - fitWidth → IntrinsicWidth
-
Available on Widget, provided by the ExpandedWidget extension
wraps the widget in a IntrinsicWidthno setter - flex → int?
-
final
- flexible → Flexible
-
Available on Widget, provided by the ExpandedWidget extension
wraps the widget in a Flexibleno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- heroTag → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- kind → ColorKinds?
-
final
- manner → ColorManners?
-
final
- margin → RemInsets?
-
final
- onLongTap → VoidCallback?
-
final
- onTap → VoidCallback?
-
final
- padding → RemInsets?
-
final
- radius → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheme → ColorSchemes?
-
final
- state → ColorStates?
-
final
- width → double?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited