ColorThemeSeed class
Constructors
- ColorThemeSeed(ColorThemeSelectors selectors, ColorThemeValues values)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- map → JsonMap
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectors → ColorThemeSelectors
-
final
- values → ColorThemeValues
-
final
Methods
-
copyWith(
{ColorThemeSelectors? selectors, ColorThemeValues? values}) → ColorThemeSeed -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited